function IndexSearch() {
	// icontains: Extension for jquery.
	// The builtin 'contains' selector is case sensitive
	// This variant ignores case
	$.expr[':'].icontains = function(obj, index, meta, stack) {
		return (obj.textContent || obj.innerText || jQuery(obj).text() || '')
			.toLowerCase()
			.indexOf(meta[3].toLowerCase()) >= 0;
	};

	this.index_sections   = undefined;
	this.matched_items    = undefined;
	this.matched_sections = undefined;
	this.hidden_items     = undefined;
	this.hidden_sections  = undefined;

	this.do_search = function (v) {
		if (this.hidden_items != undefined) {
			this.clear_search();
		}

		this.matched_items    = $('body > div.INDEX > div.INDEXDIV > dl > dt:icontains("'+v+'")');
		this.matched_sections = this.matched_items.parent().parent();
		this.hidden_sections  = this.index_sections.not(this.matched_sections).hide();
		this.hidden_items     = this.matched_sections.children().children('dt,dd').not(this.matched_items).hide();
		this.matched_items.next('dd').show();
	};

	this.clear_search = function () {
		if (this.hidden_items != undefined) {
			this.hidden_items.css('display','block');
			this.hidden_sections.css('display','block');
		}
		this.matched_items    = undefined;
		this.matched_sections = undefined;
		this.hidden_items     = undefined;
		this.hidden_sections  = undefined;
		$('#searchbox').val('');
		return false;
	};

	this.install = function () {
			$('#contentsdiv > div.footer').html('<input id="searchbox" type="text"><a id="clearsearch" href="#">X</a>');
			this.index_sections = $('body > div.INDEX > div.INDEXDIV');
			var search_obj = this;
			var delayed_search;
			$('#searchbox').keyup(function() {
				clearTimeout(delayed_search);
				var v = $(this).val();
				if (v.length >= 3) {
					delayed_search = setTimeout( function() { search_obj.do_search(v) }, 200 );
				}
				else if (v.length == 0) {
					search_obj.clear_search();
				}
			});
			$('#clearsearch').click( function() { search_obj.clear_search() } );

			$('#searchbox').select();
	};
}


function toggleTree(tgt) {
	var s = $(tgt).children('img').attr('src');
	// Next line because IE expands "src" into a full path
	s = s.substring( s.lastIndexOf('/') + 1 );
	$(tgt).children('img').attr('src', (s=='rt.png') ? 'dn.png' : 'rt.png');
	$(tgt).parent().next('dd').toggle();
	return false;
}

$(document).ready(function() {
	var url = document.location.href;
	var curr_file = url.substring( url.lastIndexOf('/') + 1, url.lastIndexOf('.')	) + '.html';

	// Insert contents div and make main bodytext thinner
	$('div.NAVHEADER')
		.after('<div id="contentsdiv" class=""><div class="header"><a class="toggle" href="#">&laquo;</a>Contents</div><div class="tree"></div><div class="footer"></div></div>')
	$('body').addClass('thin');

	// Toggle for contents div
	$('#contentsdiv > div.header > a.toggle').click(function() {
		var t = $(this).text();
		$(this).html( (t==String.fromCharCode(171)) ? String.fromCharCode(187) : String.fromCharCode(171) );
		$(this).toggleClass('closed');
		$('#contentsdiv').toggleClass('closed');
		$('body').toggleClass('thin');
		return false;
	});

	// Size height to current window, and slide control in if window is narrow.
	$('#contentsdiv div.tree').height( $(window).height() - 90 );
	if ($(window).width() <= 800) { $('#contentsdiv > div.header > a.toggle').click(); }

	// Load the tree control, and set it up
	$('#contentsdiv > div.tree').load('contentstree.dat', {}, function() {
		// Open path to the current file.
		// Need two patterns, because IE expands href into full address
		var curr_file_link = '#contentsdiv div.tree a[href="'+curr_file+'"], #contentsdiv div.tree a[href$="/'+curr_file+'"]';
		$(curr_file_link)
			.addClass('current')
			.parents('dd').prev('dt').children('a.toggle').click();
		// If the current page has a toggle link (previous sibling element), click that too
		$(curr_file_link).prev('a.toggle').click();
	});

	// Only want the search-box on the index-page
	if (curr_file == 'bookindex.html') {
		var searchbox = new IndexSearch();
		searchbox.install(); 
	}
	else {
		// Mailing list links next to headings
		//var manual_base = 'http://www.postgresql.org/docs/8.4/static/';
		var manual_base = 'http://developer.postgresql.org/pgdocs/postgres/';
		$('h1>a, h2>a, h3>a').each( function() {
			var mailing_list_link = '<a class="mlist" href="'
				+ manual_base + curr_file + '#' + $(this).attr('name') 
				+'">ML</a>';
			$(this).after(mailing_list_link)
		});
	}
});
